import Vue from 'vue'

export const CLEAR_ALL_DATA = (state) => {
    state.tabs = []
    state.selectedTab = null
}

export const setTabs = (state, tabs) => {
    state.tabs = tabs
}

export const setSelectedTab = (state, uid) => {
    state.selectedTab = uid
}

export const addTab = (state, tab) => {
    if (tab.isUrl) {
        if (tab.module.indexOf('http') === 0 || tab.module.indexOf('//') === 0) {
            window.open(tab.module)
        } else {
            let config = {
                responseType: 'arraybuffer',
                headers: { 'Content-Type': 'application/json' }
            }
            window.Vue.$flexjs.request.get(tab.module, config).then((response) => {
                let blob = new Blob([response], { type: 'application/pdf' })
                let url = window.URL.createObjectURL(blob)
                window.open(url)
            })
        }
        return false;
    }
    if (!tab.module) {
        window.Vue.$Notice['warning']({
                title: 'Opération impossible',
                desc: 'Module inexistant',
                duration: 4.5
            })
            window.Vue.$bus.$emit('module-creation', { message: 'Merci de renseigner un nom de module'})
            return false
    }
    let comp = Vue.component(tab.module)
    if (!comp) {
        window.Vue.$Notice['warning']({
            title: 'Opération impossible',
            desc: 'Module inexistant',
            duration: 4.5
        })
        window.Vue.$bus.$emit('module-creation', { message: 'Le module doit être importer à la racine de votre projet'})
        return false
    }
    let Mycomp = Vue.extend(comp)
    let myclass = new Mycomp()
    if(tab.params) {
        myclass.params = tab.params
    }
    state.tabs.push({
        item: tab.module,
        title: tab.title,
        instance: myclass
    })
    setSelectedTab(state, myclass._uid)
}

export const removeTab = (state, uid) => {
    setTabs(state, state.tabs.filter((mappedTab) => {
        return mappedTab.instance._uid !== uid
    }))
    if (state.selectedTab === uid) {
        setSelectedTab(state, (state.tabs.length > 0) ? state.tabs[state.tabs.length - 1].instance._uid : null)
    }
}
